==> openGion6.0.0.1_core.zip: uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2014/04/26 11:20:07                                            */
/****************************************************************************/
CREATE TABLE GE30 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID           */
 , PTN_ID       varchar           (   20 )                  NOT NULL            /*  20 定型文ID         */
 , FROM_ID      varchar           (   50 )                  NOT NULL            /*  30 送信者ID         */
 , TO_ID        varchar           ( 4000 )                                      /*  40 宛先(TO)         */
 , CC_ID        varchar           ( 4000 )                                      /*  50 宛先(CC)         */
 , BCC_ID       varchar           ( 4000 )                                      /*  60 宛先(BCC)        */
 , H_TXT        varchar           ( 1000 )                                      /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        varchar           ( 1000 )                                      /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    varchar           (  300 )                                      /*  90 画面URL(暗号化)  */
 , PARAM0       varchar           ( 4000 )                                      /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       varchar           ( 4000 )                                      /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       varchar           ( 1000 )                                      /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       varchar           ( 1000 )                                      /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       varchar           ( 1000 )                                      /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       varchar           ( 1000 )                                      /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       varchar           ( 1000 )                                      /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       varchar           ( 1000 )                                      /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       varchar           ( 1000 )                                      /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       varchar           ( 1000 )                                      /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      varchar           (  256 )                                      /* 200 添付1            */
 , ATTACH2      varchar           (  256 )                                      /* 210 添付2            */
 , ATTACH3      varchar           (  256 )                                      /* 220 添付3            */
 , ATTACH4      varchar           (  256 )                                      /* 230 添付4            */
 , ATTACH5      varchar           (  256 )                                      /* 240 添付5            */
 , SNDTIME      varchar           (   14 )                  NOT NULL            /* 240 送信日時         */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時         */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG           */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG         */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員         */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時         */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG           */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG         */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者           */
);

==> openGion6.1.1.0_core.zip: uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2014/12/27 18:21:17                                            */
/****************************************************************************/
CREATE TABLE GE30 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID           */
 , PTN_ID       varchar           (   20 )                  NOT NULL            /*  20 定型文ID         */
 , FROM_ID      varchar           (   50 )                  NOT NULL            /*  30 送信者ID         */
 , TO_ID        varchar           ( 4000 )                                      /*  40 宛先(TO)         */
 , CC_ID        varchar           ( 4000 )                                      /*  50 宛先(CC)         */
 , BCC_ID       varchar           ( 4000 )                                      /*  60 宛先(BCC)        */
 , H_TXT        varchar           ( 1000 )                                      /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        varchar           ( 1000 )                                      /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    varchar           (  300 )                                      /*  90 画面URL(暗号化)  */
 , PARAM0       varchar           ( 4000 )                                      /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       varchar           ( 4000 )                                      /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       varchar           ( 1000 )                                      /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       varchar           ( 1000 )                                      /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       varchar           ( 1000 )                                      /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       varchar           ( 1000 )                                      /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       varchar           ( 1000 )                                      /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       varchar           ( 1000 )                                      /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       varchar           ( 1000 )                                      /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       varchar           ( 1000 )                                      /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      varchar           (  256 )                                      /* 200 添付1            */
 , ATTACH2      varchar           (  256 )                                      /* 210 添付2            */
 , ATTACH3      varchar           (  256 )                                      /* 220 添付3            */
 , ATTACH4      varchar           (  256 )                                      /* 230 添付4            */
 , ATTACH5      varchar           (  256 )                                      /* 240 添付5            */
 , SNDTIME      varchar           (   14 )                                      /* 250 送信日次         */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時         */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG           */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG         */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員         */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時         */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG           */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG         */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者           */
);
